local addonVersion = 1
local lootTable = {}
local eligibleItems = {
    '124101', --Aethril
    --'129284', --Aethril Seed
    '124103', --Foxflower
    --'129286', --Foxflower Seed
    '124102', --Dreamleaf
    --'129285', --Dreamleaf Seed
    '124104', --Fjarnskaggl
    --'129287', --Fjarnskaggl Seed
    '124105', --Starlight Rose
    --'129288', --Starlight Rose Seed
}

local function itemEligible(itemID)
    for i = 1, #eligibleItems do
        if eligibleItems[i] == itemID then
            return true
        end
    end
    return false
end

local function onLootMessage(lootString, playerName)
    local itemID = string.match(lootString, "Hitem:(%d+):")
    local itemQuantity = string.match(lootString, "x(%d+).") or 1
    
    if itemEligible(itemID) then
        if not lootTable[itemID] then lootTable[itemID] = {} end
        if not lootTable[itemID][playerName] then lootTable[itemID][playerName] = 0 end
        lootTable[itemID][playerName] = lootTable[itemID][playerName] + tonumber(itemQuantity)
    end
end

local eventFrame = CreateFrame('Frame')
eventFrame:SetScript('OnEvent', function(self, event, ...)
    if event == 'CHAT_MSG_LOOT' then
        local lootMessage, _, _, _, playerName = ...
        onLootMessage(lootMessage, playerName)
    end
end)

local function startHerbLogging()
    eventFrame:RegisterEvent('CHAT_MSG_LOOT')
    lootTable = {}
    DEFAULT_CHAT_FRAME:AddMessage('Herb Tracker started.')
end

local function stopHerbLogging()
    eventFrame:UnregisterEvent('CHAT_MSG_LOOT')
    DEFAULT_CHAT_FRAME:AddMessage('Herb Tracker stopped.')
end


local function sortLootTable()
    for _,itemStats in pairs(lootTable) do
        table.sort(itemStats, function(a,b)
            if a > b then
                return true
            elseif a < b then
                return false
            end  
        end)
    end
end

local function reportHerbLogging(t)
    if not t then
        DEFAULT_CHAT_FRAME:AddMessage('Herb Report')
        sortLootTable()
        for k,v in pairs(lootTable) do
            local _, itemLink = GetItemInfo(k)
            DEFAULT_CHAT_FRAME:AddMessage(itemLink)
            for playerName, itemQuantity in pairs(v) do
                DEFAULT_CHAT_FRAME:AddMessage(playerName..': '..itemQuantity)
            end
        end
    elseif t == 1 then
        SendChatMessage('Herb Report', 'PARTY')
        sortLootTable()
        for k,v in pairs(lootTable) do
            local _, itemLink = GetItemInfo(k)
            SendChatMessage(itemLink, 'PARTY')
            for playerName, itemQuantity in pairs(v) do
                SendChatMessage(playerName..': '..itemQuantity, 'PARTY')
            end
        end    
    elseif t == 2 then
        SendChatMessage('Herb Report', 'RAID')
        sortLootTable()
        for k,v in pairs(lootTable) do
            local _, itemLink = GetItemInfo(k)
            SendChatMessage(itemLink, 'RAID')
            for playerName, itemQuantity in pairs(v) do
                SendChatMessage(playerName..': '..itemQuantity, 'RAID')
            end
        end        
    end
end

SLASH_HERBTRACKER1 = '/herbtracker'
SLASH_HERBTRACKER2 = '/herbt'
SlashCmdList['HERBTRACKER'] = function(s)
    if s == 'start' then
        startHerbLogging()
    elseif s == 'stop' then
        stopHerbLogging()
        reportHerbLogging()
    elseif s == 'report' then
        reportHerbLogging()
    elseif s == 'party' then
        reportHerbLogging(1)
    elseif s == 'raid' then
        reportHerbLogging(2)
    else
        DEFAULT_CHAT_FRAME:AddMessage('Type /herbtracker start to start logging, stop to stop logging.')
        DEFAULT_CHAT_FRAME:AddMessage('Type /herbtracker report to see current report.')
        DEFAULT_CHAT_FRAME:AddMessage('Type /herbtracker party to say report in party.')
        DEFAULT_CHAT_FRAME:AddMessage('Type /herbtracker raid to say report in raid.')
    end
end
